@@ -11,7 +11,7 @@ _=(0,0)  # _____________________________________________________________________
 # fmt: on
 
 try:
-    from typing import TYPE_CHECKING
+    TYPE_CHECKING = False
 except:
     TYPE_CHECKING = False
 
@@ -60,10 +60,6 @@ web/browser.js
 web/browser2.html
 web/cf.html
 web/copyparty.gif
-web/dd/2.png
-web/dd/3.png
-web/dd/4.png
-web/dd/5.png
 web/deps/busy.mp3
 web/deps/easymde.css
 web/deps/easymde.js
@@ -77,6 +73,7 @@ web/deps/prismd.css
 web/deps/scp.woff2
 web/deps/sha512.ac.js
 web/deps/sha512.hw.js
+web/idp.html
 web/iiam.gif
 web/md.css
 web/md.html
@@ -111,7 +108,9 @@ class EnvParams(object):
     def __init__(self)  :
         self.t0 = time.time()
         self.mod = ""
+        self.mod_ = ""
         self.cfg = ""
+        self.scfg = True
 
 
 E = EnvParams()
