@@ -2,7 +2,6 @@
 from __future__ import print_function, unicode_literals
 
 import argparse
-import traceback
 
 from queue import Queue
 
@@ -23,11 +22,23 @@ class ExceptionalQueue(Queue, object):
                 if rv[1] == "pebkac":
                     raise Pebkac(*rv[2:])
                 else:
-                    raise Exception(rv[2])
+                    raise rv[2]
 
         return rv
 
 
+class NotExQueue(object):
+    """
+    BrokerThr uses this instead of ExceptionalQueue; 7x faster
+    """
+
+    def __init__(self, rv )  :
+        self.rv = rv
+
+    def get(self)  :
+        return self.rv
+
+
 class BrokerCli(object):
     """
     helps mypy understand httpsrv.broker but still fails a few levels deeper,
@@ -43,7 +54,7 @@ class BrokerCli(object):
     def __init__(self)  :
         pass
 
-    def ask(self, dest , *args )  :
+    def ask(self, dest , *args )   :
         return ExceptionalQueue(1)
 
     def say(self, dest , *args )  :
@@ -60,8 +71,8 @@ def try_exec(want_retval  , func , *args )  :
 
         return ["exception", "pebkac", ex.code, str(ex)]
 
-    except:
+    except Exception as ex:
         if not want_retval:
             raise
 
-        return ["exception", "stack", traceback.format_exc()]
+        return ["exception", "stack", ex]
