@@ -44,6 +44,7 @@ def vf_bmap()   :
         "gsel",
         "hardlink",
         "magic",
+        "md_no_br",
         "no_db_ip",
         "no_sb_md",
         "no_sb_lg",
@@ -56,6 +57,7 @@ def vf_bmap()   :
         "rmagic",
         "rss",
         "wo_up_readme",
+        "wram",
         "xdev",
         "xlink",
         "xvol",
@@ -80,9 +82,11 @@ def vf_vmap()   :
     }
     for k in (
         "bup_ck",
+        "casechk",
         "chmod_d",
         "chmod_f",
         "dbd",
+        "du_who",
         "forget_ip",
         "hsortn",
         "html_head",
@@ -106,6 +110,7 @@ def vf_vmap()   :
         "put_name",
         "mv_retry",
         "rm_retry",
+        "shr_who",
         "sort",
         "tail_fd",
         "tail_rate",
@@ -183,6 +188,7 @@ flagcats = {
         "chmod_f=644": "unix-permission for new files",
         "uid=573": "change owner of new files/folders to unix-user 573",
         "gid=999": "change owner of new files/folders to unix-group 999",
+        "wram": "allow uploading into ramdisks",
         "sparse": "force use of sparse files, mainly for s3-backed storage",
         "nosparse": "deny use of sparse files, mainly for slow storage",
         "daw": "enable full WebDAV write support (dangerous);\nPUT-operations will now \033[1;31mOVERWRITE\033[0;35m existing files",
@@ -213,6 +219,7 @@ flagcats = {
     "upload rotation\n(moves all uploads into the specified folder structure)": {
         "rotn=100,3": "3 levels of subfolders with 100 entries in each",
         "rotf=%Y-%m/%d-%H": "date-formatted organizing",
+        "rotf_tz=Europe/Oslo": "timezone (default=UTC)",
         "lifetime=3600": "uploads are deleted after 1 hour",
     },
     "database, general": {
@@ -241,6 +248,7 @@ flagcats = {
         "no_db_ip": "never store uploader-IP in the db; disables unpost",
         "fat32": "avoid excessive reindexing on android sdcardfs",
         "dbd=[acid|swal|wal|yolo]": "database speed-durability tradeoff",
+        "casechk=auto": "actively prevent case-insensitive filesystem? y/n",
         "xlink": "cross-volume dupe detection / linking (dangerous)",
         "xdev": "do not descend into other filesystems",
         "xvol": "do not follow symlinks leaving the volume root",
@@ -295,6 +303,7 @@ flagcats = {
         "html_head=TXT": "includes TXT in the <head>, or @PATH for file at PATH",
         "tcolor=#fc0": "theme color (a hint for webbrowsers, discord, etc.)",
         "nodirsz": "don't show total folder size",
+        "du_who=all": "show disk-usage info to everyone",
         "robots": "allows indexing by search engines (default)",
         "norobots": "kindly asks search engines to leave",
         "unlistcr": "don't list read-access in controlpanel",
@@ -324,6 +333,7 @@ flagcats = {
         "og_ua": "if defined: only send OG html if useragent matches this regex",
     },
     "textfiles": {
+        "md_no_br": "newline only on double-newline or two tailing spaces",
         "md_hist": "where to put markdown backups; s=subfolder, v=volHist, n=nope",
         "exp": "enable textfile expansion; see --help-exp",
         "exp_md": "placeholders to expand in markdown files; see --help",
@@ -346,6 +356,7 @@ flagcats = {
         "dky": 'allow seeing files (not folders) inside a specific folder\nwith "g" perm, and does not require a valid dirkey to do so',
         "rss": "allow '?rss' URL suffix (experimental)",
         "rmagic": "expensive analysis for mimetype accuracy",
+        "shr_who=auth": "who can create shares? no/auth/a",
         "unp_who=2": "unpost only if same... 1=ip+name, 2=ip, 3=name",
         "ups_who=2": "restrict viewing the list of recent uploads",
         "zip_who=2": "restrict access to download-as-zip/tar",
