@@ -50,6 +50,11 @@ class U2idx(object):
             self.log("your python does not have sqlite3; searching will be disabled")
             return
 
+        if self.args.srch_icase:
+            self._open_db = self._open_db_icase
+        else:
+            self._open_db = self._open_db_std
+
 
         self.active_id = ""
         self.active_cur  = None
@@ -65,6 +70,15 @@ class U2idx(object):
     def log(self, msg , c   = 0)  :
         self.log_func("u2idx", msg, c)
 
+    def _open_db_std(self, *args, **kwargs):
+        kwargs["check_same_thread"] = False
+        return sqlite3.connect(*args, **kwargs)
+
+    def _open_db_icase(self, *args, **kwargs):
+        db = self._open_db_std(*args, **kwargs)
+        db.create_function("casefold", 1, lambda x: x.casefold() if x else x)
+        return db
+
     def shutdown(self)  :
         if not HAVE_SQLITE3:
             return
@@ -142,8 +156,7 @@ class U2idx(object):
             uri = ""
             try:
                 uri = "{}?mode=ro&nolock=1".format(Path(db_path).as_uri())
-                db = sqlite3.connect(uri, timeout=2, uri=True, check_same_thread=False)
-                cur = db.cursor()
+                cur = self._open_db(uri, timeout=2, uri=True).cursor()
                 cur.execute('pragma table_info("up")').fetchone()
                 self.log("ro: %r" % (db_path,))
             except:
@@ -154,7 +167,7 @@ class U2idx(object):
         if not cur:
             # on windows, this steals the write-lock from up2k.deferred_init --
             # seen on win 10.0.17763.2686, py 3.10.4, sqlite 3.37.2
-            cur = sqlite3.connect(db_path, timeout=2, check_same_thread=False).cursor()
+            cur = self._open_db(db_path, timeout=2).cursor()
             self.log("opened %r" % (db_path,))
 
         self.cur[ptop] = cur
@@ -167,6 +180,8 @@ class U2idx(object):
         if not HAVE_SQLITE3:
             return [], [], False
 
+        icase = self.args.srch_icase
+
         q = ""
         v   = ""
         va   = []
@@ -226,9 +241,13 @@ class U2idx(object):
                 elif v == "path":
                     v = "trim(?||up.rd,'/')"
                     va.append("\nrd")
+                    if icase:
+                        v = "casefold(%s)" % (v,)
 
                 elif v == "name":
                     v = "up.fn"
+                    if icase:
+                        v = "casefold(%s)" % (v,)
 
                 elif v == "tags" or ptn_mt.match(v):
                     have_mt = True
@@ -279,6 +298,12 @@ class U2idx(object):
                     tail = "||'%'"
                     v = v[:-1]
 
+            if icase and "casefold(" in q:
+                try:
+                    v = unicode(v).casefold()
+                except:
+                    v = unicode(v).lower()
+
             q += " {}?{} ".format(head, tail)
             va.append(v)
             is_key = True
@@ -313,7 +338,7 @@ class U2idx(object):
         uname ,
         vols ,
         uq ,
-        uv  ,
+        uv   ,
         have_mt ,
         sort ,
         lim ,
